Documentation
¶
Overview ¶
Package testutil provides useful testing helpers.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Logger ¶
func Logger(t HelpLogger) (*zap.Logger, func())
Logger returns a zap logger which logs to a test, and a stop function. The caller must defer the stop function to prevent panics from background goroutines that log after the test has exited.
Types ¶
type HelpLogger ¶
HelpLogger is an interface with Helper and Logf functions.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package miniredistest provides a test redis server.
|
Package miniredistest provides a test redis server. |
Click to show internal directories.
Click to hide internal directories.